summaryrefslogtreecommitdiffstats
path: root/buildtools/lib/parsers/qmake/qmake_lex.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/lib/parsers/qmake/qmake_lex.h')
-rw-r--r--buildtools/lib/parsers/qmake/qmake_lex.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/buildtools/lib/parsers/qmake/qmake_lex.h b/buildtools/lib/parsers/qmake/qmake_lex.h
index 242cec2a..514631bf 100644
--- a/buildtools/lib/parsers/qmake/qmake_lex.h
+++ b/buildtools/lib/parsers/qmake/qmake_lex.h
@@ -1,4 +1,4 @@
/* KDevelop QMake Support
*
* Copyright 2007 Andreas Pakulat <apaku@gmx.de>
*
@@ -17,8 +17,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
* 02110-1301, USA.
*/
-#ifndef QMAKE_LEX_H
-#define QMAKE_LEX_H
+#ifndef TQMAKE_LEX_H
+#define TQMAKE_LEX_H
#include "qmake_yacc.hpp"
#include <iostream>
@@ -27,23 +27,23 @@
#include "FlexLexer.h"
#endif
-namespace QMake
+namespace TQMake
{
class Lexer : public yyFlexLexer
{
public:
enum LineEnding{ None, Unix, MacOS, Windows };
Lexer( std::istream* argin = 0, std::ostream* argout = 0 );
- int yylex( QMake::Parser::semantic_type* yylval );
+ int yylex( TQMake::Parser::semantic_type* yylval );
int yylex();
void setLineEndingFromString( const TQString& );
LineEnding lineending();
private:
- QMake::Parser::semantic_type* mylval;
+ TQMake::Parser::semantic_type* mylval;
LineEnding m_lineEnding;
};
}
#endif
-// kate: space-indent on; indent-width 4; tab-width: 4; replace-tabs on; auto-insert-doxygen on
+// kate: space-indent on; indent-width 4; tab-width: 4; tqreplace-tabs on; auto-insert-doxygen on
@@ -1,4 +1,4 @@
-/* KDevelop QMake Support
+/* KDevelop TQMake Support
*
* Copyright 2007 Andreas Pakulat <apaku@gmx.de>